@@ -24,7 +24,7 @@
 
 import libxml2
 from rteval.modules import RtEvalModules, ModuleContainer
-
+from rteval.systopology import collapse_cpulist, CpuList, SysTopology as SysTop
 
 class MeasurementProfile(RtEvalModules):
     """Keeps and controls all the measurement modules with the same measurement profile"""
@@ -89,7 +89,7 @@ class MeasurementProfile(RtEvalModules):
         if self.__run_parallel:
             return self._isAlive()
 
-        if len(self.__serialised_mods) > 0:
+        if self.__serialised_mods:
             # If running serialised, first check if measurement is still running,
             # if so - return True.
             mod = self.GetNamedModuleObject(self.__serialised_mods[0])
@@ -98,7 +98,7 @@ class MeasurementProfile(RtEvalModules):
 
             # If not, go to next on the list and kick it off
             self.__serialised_mods.remove(self.__serialised_mods[0])
-            if len(self.__serialised_mods) > 0:
+            if self.__serialised_mods:
                 mod = self.GetNamedModuleObject(self.__serialised_mods[0])
                 mod.setStart()
                 return True
@@ -107,7 +107,7 @@ class MeasurementProfile(RtEvalModules):
         return False
 
 
-class MeasurementModules(object):
+class MeasurementModules:
     """Class which takes care of all measurement modules and groups them into
 measurement profiles, based on their characteristics"""
 
@@ -189,6 +189,14 @@ measurement profiles, based on their characteristics"""
 
         # Get the reports from all meaurement modules in all measurement profiles
         rep_n = libxml2.newNode("Measurements")
+        cpulist = self.__cfg.GetSection("measurement").cpulist
+        if cpulist:
+            # Convert str to list and remove offline cpus
+            cpulist = CpuList(cpulist).cpulist
+        else:
+            cpulist = SysTop().online_cpus()
+        rep_n.newProp("measurecpus", collapse_cpulist(cpulist))
+
         for mp in self.__measureprofiles:
             mprep_n = mp.MakeReport()
             if mprep_n:
@@ -211,6 +219,6 @@ MeasurementProfile object to be processed"""
         if self.__iter_item == 0:
             self.__iter_item = None
             raise StopIteration
-        else:
-            self.__iter_item -= 1
-            return self.__measureprofiles[self.__iter_item]
+
+        self.__iter_item -= 1
+        return self.__measureprofiles[self.__iter_item]
