@@ -32,9 +32,9 @@ from rteval.sysinfo.services import SystemServices
 from rteval.sysinfo.cputopology import CPUtopology
 from rteval.sysinfo.memory import MemoryInfo
 from rteval.sysinfo.osinfo import OSInfo
-from rteval.sysinfo.network import NetworkInfo
+from rteval.sysinfo.newnet import NetworkInfo
 from rteval.sysinfo.cmdline import cmdlineInfo
-import rteval.sysinfo.dmi as dmi
+from rteval.sysinfo import dmi
 
 class SystemInfo(KernelInfo, SystemServices, dmi.DMIinfo, CPUtopology,
                  MemoryInfo, OSInfo, NetworkInfo, cmdlineInfo):
@@ -42,13 +42,14 @@ class SystemInfo(KernelInfo, SystemServices, dmi.DMIinfo, CPUtopology,
         self.__logger = logger
         KernelInfo.__init__(self, logger=logger)
         SystemServices.__init__(self, logger=logger)
-        dmi.DMIinfo.__init__(self, config, logger=logger)
+        dmi.DMIinfo.__init__(self, logger=logger)
         CPUtopology.__init__(self)
         OSInfo.__init__(self, logger=logger)
         cmdlineInfo.__init__(self, logger=logger)
+        NetworkInfo.__init__(self, logger=logger)
 
         # Parse initial DMI decoding errors
-        dmi.ProcessWarnings()
+        dmi.ProcessWarnings(logger=logger)
 
         # Parse CPU info
         CPUtopology._parse(self)
@@ -80,8 +81,8 @@ if __name__ == "__main__":
     cfg.installdir = "."
     si = SystemInfo(cfg, logger=l)
 
-    print("\tRunning on %s" % si.get_base_os())
-    print("\tNUMA nodes: %d" % si.mem_get_numa_nodes())
+    print(f"\tRunning on {si.get_base_os()}")
+    print(f"\tNUMA nodes: {si.mem_get_numa_nodes()}")
     print("\tMemory available: %03.2f %s\n" % si.mem_get_size())
 
     print("\tServices: ")
